Mixed-Up Code Exercises
-----------------------

Answer the following **Mixed-Up Code** or **Activecode** questions to
assess what you have learned in this chapter.

.. selectquestion:: mucp_11_1_sq
   :fromid: mucp_11_1, mucp_11_1_ac_q
   :toggle:

.. selectquestion:: mucp_11_2_sq
   :fromid: mucp_11_2, mucp_11_2_ac_q
   :toggle:

.. selectquestion:: mucp_11_3_sq
   :fromid: mucp_11_3, mucp_11_3_ac_q
   :toggle:

.. selectquestion:: mucp_11_4_sq
   :fromid: mucp_11_4, mucp_11_4_ac_q
   :toggle:

.. selectquestion:: mucp_11_5_sq
   :fromid: mucp_11_5, mucp_11_5_ac_q
   :toggle:

.. selectquestion:: mucp_11_6_sq
   :fromid: mucp_11_6, mucp_11_6_ac_q
   :toggle:

.. selectquestion:: mucp_11_7_sq
   :fromid: mucp_11_7, mucp_11_7_ac_q
   :toggle:

.. selectquestion:: mucp_11_8_sq
   :fromid: mucp_11_8, mucp_11_8_ac_q
   :toggle:

.. selectquestion:: mucp_11_9_sq
   :fromid: mucp_11_9, mucp_11_9_ac_q
   :toggle:

.. selectquestion:: mucp_11_10_sq
   :fromid: mucp_11_10, mucp_11_10_ac_q
   :toggle:
